==> vue-scroll-1.0.3.tgz: package/lib/vue-scroll.browser.js <==
;(function(undefined){

  var Vue = window.Vue;

  //Common part start

  if(!Vue) {
    throw new Error('Please load vue.js before install current plugin');
  }

  var vScroll = {};

  vScroll.install = function(Vue,options){

    Vue.directive('scroll', {
        bind: function () {
          var self = this,
             el = this.el,
             vm = this.vm,
             listener = vm[self.expression];
          if(el.addEventListener){
              el.addEventListener('scroll',function(e){
                listener && listener(e, { scrollTop: el.scrollTop, scrollLeft: el.scrollLeft});
              });
          }else{
              el.attach('onscroll',function(){
                var e = window.event;
                listener && listener(e, { scrollTop: el.scrollTop, scrollLeft: el.scrollLeft});
              });
          }

        },
        update: function (newListener, oldListener) {
          //replace old listener by new listener
          var self = this,
             el = this.el;
          if(el.addEventListener){
              el.removeEventListener('scroll',oldListener);
              el.addEventListener('scroll',function(e){
                newListener && newListener(e, { scrollTop: el.scrollTop, scrollLeft: el.scrollLeft});
              });
          }else {
              el.detachEvent('onscroll',oldListener);
              el.attach('onscroll',function(){
                var e = window.event;
                newListener && newListener(e, { scrollTop: el.scrollTop, scrollLeft: el.scrollLeft});
              });
          }
        },
        unbind: function () {
          var self = this,
               el = this.el,
               vm = this.vm,
               listener = vm[self.expression];
          if(el.removeEventListener){
            el.removeEventListener('scroll',listener);
          }else{
            el.detachEvent('onscroll',listener);
          }     
        }
    });

  }

  //Common part start

  Vue.use(vScroll);  
  
})(undefined)

==> vue-scroll-1.0.4.tgz: package/lib/vue-scroll.browser.js <==
;(function(undefined){

  var Vue = window.Vue;

  //Common part start

  if(!Vue) {
    throw new Error('Please load vue.js before install current plugin');
  }

  var vScroll = {};

  vScroll.install = function(Vue,options){

    Vue.directive('scroll', {
        bind: function () {
          console.log('prepare for bind vue-scroll on specify dom');
        },
        update: function (newListener, oldListener) {
          //replace old listener by new listener
          var self = this,
             el = this.el;
          if(!newListener || typeof newListener !== 'function'){
            throw new Error('onScroll listener is not a valid function');
          }
          if(el==document.body){
            document.onscroll = function(e){
              newListener && newListener(e, { scrollTop: document.body.scrollTop, scrollLeft: document.body.scrollLeft});
            }
          }else if(el.addEventListener){
              el.removeEventListener('scroll',oldListener);
              el.addEventListener('scroll',function(e){
                newListener && newListener(e, { scrollTop: el.scrollTop, scrollLeft: el.scrollLeft});
              });
          }else {
              el.detachEvent('onscroll',oldListener);
              el.attach('onscroll',function(){
                var e = window.event;
                newListener && newListener(e, { scrollTop: el.scrollTop, scrollLeft: el.scrollLeft});
              });
          }
        },
        unbind: function () {
          var self = this,
               el = this.el,
               vm = this.vm,
               listener = vm[self.expression];
          if(el==document.body){
            document.onscroll = null;
          }else if(el.removeEventListener){
            el.removeEventListener('scroll',listener);
          }else{
            el.detachEvent('onscroll',listener);
          }     
        }
    });

  }

  //Common part start

  Vue.use(vScroll);  
  
})(undefined)
